<?php
/**
 * This file is part of
 * pragmaMx - Web Content Management System.
 * Copyright by pragmaMx Developer Team - http://www.pragmamx.org
 *
 * pragmaMx is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * $Revision: 636 $
 * $Author: PragmaMx $
 * $Date: 2022-10-24 07:41:49 +0200 (Mo, 24. Okt 2022) $
 */
 
defined('mxMainFileLoaded') or die('access denied');
 
if (!mxGetAdminPref("radminsuper")) {
    mxErrorScreen("Access Denied");
    die();
} 
 
// Modulname aufloesen
$module_name = basename(dirname(dirname(__FILE__)));

/***
 * Sprachfile: Backend und Frontend getrennt
 * deswegen auf diesem Weg das einbinden
 ***/
if (!defined('_STRUCTURE_BACKEND')) {
    mxGetLangfile($module_name, 'admin.lang-*.php');
}

// Versionsabbruch
if (version_compare(PMX_VERSION, '2.2.5', '<')){
	include_once('header.php');
	echo '<div>&nbsp;</div>';
	echo '<h2>' . _stc_STRUCTURE . '</h2>';
	if(MX_IS_ADMIN){
		echo _stc_SYSTEM_ERROR_ADMIN;
	}else{
		echo _stc_SYSTEM_ERROR_USER;
	}
	include_once('footer.php');
	exit;
}




// Datenbank-Tabellen anlegen notfalls
include(PMX_MODULES_DIR . DS . $module_name . DS . "core/install.tabledef.php");	
stcMakeTables();

// Funktionen einbinden
include(PMX_MODULES_DIR . DS . $module_name . DS . "includes/functions.php");
include(PMX_MODULES_DIR . DS . $module_name . DS . "includes/db.functions.php");	
include(PMX_MODULES_DIR . DS . $module_name . DS . "includes/default_config.php");	
include(PMX_MODULES_DIR . DS . $module_name . DS . "includes/default_values.php");


// vars
if(empty($act)) $act = '';

// Tue was
switch ($act) {
	case "activate":
		mxSetModuleActive($module_name, '1');
		structureMain();
		break;
	
	case "show_welcome_off":
		stcWelcomeOff();
		header("Location: admin.php?op=$module_name");
		break;
		
	case "settings":
	   stcSettings();
	   break;
	   
	case "categorys":
		stcCategorys();
		break;
		
	case "add_categorys":
		stcCategorysContent();
		break;	

	case "category_activate":
	case "category_deactivate":
		stcCategoryStatus($what, $cid);
		break;		
	case "categorys_delete":
		stcShowDeleteCategorys();
		break;
	
	case "category_delete_force":
		stcDeleteCategorys($pvs);
		header("Location: admin.php?op=$module_name&act=categorys");
		break;
		
	case "category_edit_all":
		stcEditCategorysAll();
		break;

	case "content":
		stcMakeBoxSetSession($box);
		stcContent();
		break;
	case "content_activate":
	case "content_deactivate":
		stcContentStatus($what, $cid, $cat_id);
		break;

	case "content_show":
		stcShowContent();
		break;
	
	case "content_delete":
		stcShowDeleteContent();
		break;
	
	case "delete_image":
		stcOnlyDeleteImage();
		break;		
		
	case "content_move":
		stcMoveContent();
		break;
			
    default:
    	structureMain();
		break;
}



/***
* structureMain()
*Startansicht Adminbereich
***/
function structureMain(){
	global $prefix, $module_name;
	// Costumstyle CSS
	
	// Test ob Modul aktiviert ist
	$error = (!mxModuleActive($module_name))?"<div class=\"\">" . _MODULENOTACTIVE . " <a href=\"admin.php?op=".$module_name."&amp;act=activate\" class=\"button\" >"._ACTIVATE."</a></div>":"";

	//config holen
	$config = load_class('Config',$module_name);	
	$stc_config=$config->get();
	$control_var = true;

	
	if(empty($stc_config)){
		$control_var = false;
	}
	
	$default_config = defaultConfig();
	$stc_config = array_merge( $default_config, $stc_config);

	//vars
	if(empty($achtung)) $achtung = '';
	$view_icon = '<img title="' . _stc_CONTENT_TOOLTIP . '" src="modules/' . $module_name . '/images/preview.png" width="15px" alt="" />';
	$edit_icon = '<img title="' . _stc_USER_TOOLTIP . '" src="modules/' . $module_name . '/images/edit.gif" width="15px" alt="" />';
	
	$tb = load_class('AdminForm', "adminFormMain");

	// Auswertung von Klickfunktion
	switch (pmxAdminForm::CheckButton()) {
		case "config":
			stcSettings();
			exit;
			break;
		
		case "folder":
			stcCategorys();
			exit;
			break;
			
	    default:
        break;
	}

	$tb->__set('title','' . imgModul() . '  ' . _stc_STRUCTURE . '');
	$tb->__set('description',"");
    $tb->__set("tb_text", "");
    $tb->__set("tb_direction", 'right');
    $tb->__set("infobutton", true);
    $tb->__set("tb_pic_heigth", 22);
    $tb->__set("cssclass", "toolbar1");
    $tb->__set('acceptbutton', false);
    $tb->__set('homelink', false);
	$tb->__set('tb_pic_alternate_path',"modules/$module_name/images/adminform/"); 

	if($control_var){
		$tb->addToolbar('folder',_stc_BOX);
	}
	$tb->addToolbar("config", _stc_BUTTON_SETTINGS);	

	if($stc_config['show_welcome'] == "1"){	
		$tb->addFieldSet("welcome", _stc_WELCOMEBOX_HEAD ,'',false);
		
		$welcome_msg  = _stc_WELCOMEBOX_MSG;
		$welcome_msg .='<div>&nbsp;</div><div>&nbsp;</div>';

		$welcome_box_out = '<div class="tiny">' . sprintf( _stc_WELCOMEBOX_OFF, $module_name) . '</div>';
		
		// Welcombox zusammenbauen
		$make_box = $welcome_msg.$welcome_box_out;
		$tb->add("welcome",'html', $make_box);
	}
	
	// hier klaeren ob Useruebersicht mit angezeigt wird
	switch ($stc_config['user_system']){
		case "1":
			// Daten holen zu den Useraenderungen
			$result_content = sql_query("SELECT con_id, con_category, con_owner, con_title, con_desc, con_image, con_function FROM " . $prefix . "_structure_content_temp");
			$count_edit = sql_num_rows($result_content);
			
			if($count_edit >= "1"){
				// setzen von CCS Klassen und Icon
				$colClass = array("alternate","alternate-b");
				$a = count($colClass);
				$i ='0';
				$achtung = '<img src="modules/' . $module_name . '/images/danger.png" width="15px">';
				$anzeige = '<table class="full list">';
				while(list($con_id, $con_category, $con_owner, $con_title, $con_desc, $con_image, $con_function) = sql_fetch_row($result_content)){
					$anzeige .='<tr class="' . $colClass[$i%count($colClass)] . '">
							   	 <td>' . $con_owner . ' (' . $con_title . ')</td>
							   	 <td style="text-align:center"><a href="admin.php?op=' . $module_name . '&act=content_show&insertid=' . $con_id . '&box='.$con_category.'">' . $edit_icon . '</a></td>
							  </tr>';
							  $i++;
				}
				$anzeige .= '</table>';
			}else{
				$anzeige = _stc_NOENTRY;
			}
			
			$tb->addFieldSet("edit_user_data", '' . $achtung . ' ' . _stc_USEREDIT . ' ', "", false, array("style" => "width:33%;float:right;"));
			$tb->add("edit_user_data",'html',$anzeige);
			
			// User
			$tb->addFieldSet("viewusers", _stc_SYSUSER, "", false, array("style" => "width:33%;float:right;"));
			$result_user = sql_query("SELECT con_id, con_category, con_owner, con_title FROM " . $prefix . "_structure_content");
			$count_user = sql_num_rows($result_user);
			if($count_user >= "1"){
				// setzen von CCS Klassen und Icon
				$colClass = array("alternate","alternate-b");
				$a = count($colClass);
				$i ='0';
				$anzeige_2 = '<table class="full list">';
				while(list($con_id, $con_category, $con_owner, $con_title) = sql_fetch_row($result_user)){
					// jetzt noch Testen ob User ein System User ist
					$userdata = false;
					$userdata = mxGetUserDataFromUsername($con_owner);
					if($userdata){
						$anzeige_2 .='<tr class="' . $colClass[$i%count($colClass)] . '">
						   	 <td>' . $con_owner . ' (' . $con_title . ')</td>
						   	 <td style="text-align:center"><a title="' . _stc_USER_TOOLTIP . '" href="admin.php?op=' . $module_name . '&act=content_show&insertid=' . $con_id . '&box='.$con_category.'">' . $edit_icon . '</a></td>
						  </tr>';
						  $i++;	
					}
				}
				$anzeige_2 .= '</table>';
			}
			else{
				$anzeige_2 = _stc_NOENTRY;
			}
			
			$tb->add("viewusers",'html',$anzeige_2);
			
			/* ab hier:  die Breite von der Uebersicht */
			$collapsed = true;
			$width= 33;
			break;
			
		case "0":
			$width = 100;
			$collapsed = false;
			break;		
	}

	// Uebersichten holen und Icon anklemmen
	$result = sql_query("SELECT cat_id,cat_name, cat_counter FROM " . $prefix . "_structure_category order by cat_sorting asc");
	$count = sql_num_rows($result);
	if($count >= "1"){
		$viewall = '<table class="full list">';
		// setzen von CCS Klassen und Icon
		$colClass = array("alternate","alternate-b");
		$a = count($colClass);
		$i ='0';		
		while(list($cat_id,$cat_name, $cat_counter) = sql_fetch_row($result)){
			$viewall .= '<tr class="' . $colClass[$i%count($colClass)] . '">
				    <td>' . $cat_name . '</td>
				    <td>' . $cat_counter . '</td>
				    <td style="text-align:center"><a href="admin.php?op=' . $module_name . '&act=content&box=' . $cat_id . '">' . $view_icon . '</a></td>
				  </tr>';
			$i++;
		}
		$viewall .= '</table>';//<div style="clear: both;"></div>
	}else{
		$viewall = _stc_NOENTRY;
	}
	$tb->addFieldSet("viewall", _stc_CONTENT_VIEWALL, "", false, array("style" => "width:" . $width . "%;"));
    $tb->add("viewall","html",  $viewall);	

	$form=$tb->Show();
	unset($tb);
	
	/*
     * Template
     */
    $template = load_class('Template');
    $template->init_path(__FILE__);	
		
	/* hier die Ausgabefelder angeben */
	$template->assign(compact('form','error'));	

	mxIncludeHeader();;
		$template->display("admin/main.html");
	mxIncludeFooter();
	
}


/***
* 
* 
***/
function stcSettings(){
	global $module_name;

	$config = load_class('Config',$module_name);	
	load_class('AdminForm');
	
	$redirect=true;		

	// Config hier vorladen
	$stc_config=$config->get();
	$default_config = defaultConfig();
	$stc_config = array_merge($default_config,$stc_config);
	
	// Auswertung von Klickfunktion
	switch (pmxAdminForm::CheckButton()) {
		case "accept":
			$redirect=false;

		case "save":
			$pvs = $_POST;
			$upload_dir = Strip_tags(str_replace ("\\", "/", mxStripSlashes($_POST['upload_path'])));
			$upload_dir = rtrim($upload_dir, " \\ /");
			// Verzeichnis nur auswerten wenn Upload erlaubt
			if($pvs['image_upload'] == "1"){
				$error = false;
				mxSessionSetVar('stc_upload_access','1');
				$dir_test = "modules/$module_name/$upload_dir";
				mxSessionSetVar('stc_upload_dir', $upload_dir); 
				if(file_exists($dir_test)){
					$permsdir = decoct(fileperms($dir_test));
					$perms = substr($permsdir, -3);
					if ($perms != "777" || $dir_test == "") {
						$upload_dir = '<strong>' . $dir_test . '</strong> --- ';
						$error[] = sprintf(_stc_INFO_UPLOAD_NOTOK, $upload_dir);
						mxSessionSetVar('stc_upload_error', $error); 
					}
				}else{
					
					$error[] = _stc_DIR_UNVAILABLE; 
					mxSessionSetVar('stc_upload_error', $error);
				}
			
				if($error){
					header("Location: admin.php?op=$module_name&act=settings");
					exit;
				}
				$pvs['upload_path']  = $upload_dir;
			}
			
			$pvs['upload_path']  = $upload_dir;
			
			stcSaveSettings($pvs);
			if($redirect){
				mxRedirect("admin.php?op=$module_name", _CHANGESAREOK, 1);
			}		
			break;
		
	    default:
        break;
	}	
	
	/* config neu einlesen */
	$stc_config=$config->get();
	$stc_config = array_merge($default_config,$stc_config);

	/* Werte ueberschreiben */
	$post__check__dir = false;
	$post__check__dir = mxSessionGetVar('stc_upload_dir');	
	if($post__check__dir){
		$stc_config['upload_path'] = $post__check__dir;
		$stc_config['image_upload'] = mxSessionGetVar('stc_upload_access');
	}
	mxSessionDelVar('stc_upload_dir');
	mxSessionDelVar('stc_upload_access');	
	
	// Templateverzeichnis durchlaufen
	$ordner = "modules/$module_name/templates/design";
	$alledateien = scandir($ordner);
	
	// Filtern von Designs
	foreach ($alledateien as $datei) {
		if(($datei != '.') && ($datei != '..') && ($datei != '_blankDesign') && is_dir(''.$ordner.'/' . $datei.'')) {
			$designselector[$datei] = $datei;
		}
	}
	
	// Infomessage vorbereiten
	$uploaddir_not_ok = '<img title="" src="modules/' . $module_name . '/images/status_off.png" style="width:18px" alt="" />';
	$uploaddir_is_ok = '<img title="" src="modules/' . $module_name . '/images/status_on.png" style="width:18px" alt="" />';
	$msg  = '<strong>' . _stc_INFO_UPLOAD_DIR . ':</strong> <div class="tiny">(' . _stc_INFO_UPLOAD_DIR_INFO . ' )</div>';
	$msg .= '<div>&nbsp;</div>';
	$msg .=  sprintf( _stc_INFO_UPLOAD_OK, $uploaddir_is_ok );
	$msg .='<br>';
	$msg .=  sprintf( _stc_INFO_UPLOAD_NOTOK, $uploaddir_not_ok );
	$msg .= '<div>&nbsp;</div>';
	$msg .= '<div>' . _stc_UPLOAD_HELP . '</div>';
	$msg .= '<div>&nbsp;</div>';
	
	// Infomessage fuer Userverwaltung
	$sys_msg = '<strong>' . _stc_INFO_USER . ':</strong>';
	$sys_msg .= '<div>&nbsp;</div>';
	$sys_msg .= _stc_INFO_USER_MSG;
	$sys_msg .= '<div>&nbsp;</div>';
	
	/* Verzeichnis test */
	$checkdir = checkUploadDir($stc_config['upload_path']) ;
	
	$tb = new pmxAdminForm("adminFormMain");
		
	$tb->__set('title','' . imgModul() . '  ' . _stc_STRUCTURE . ' - ' . _stc_SETTINGS . '');
	$tb->__set('description',"");
	$tb->__set("tb_text", _stc_SETTINGS_HEAD_MSG);
	$tb->__set("tb_direction", 'right');
	$tb->__set("infobutton", true);
	$tb->__set("tb_pic_heigth", 22);
	$tb->__set('homelink', true);
	$tb->__set('target_url', "admin.php?op=" . $module_name . "&act=settings");	
	
	$tb->addToolbar("accept");
	$tb->addToolbar("save");
	$tb->addToolbarSpace();
	#$tb->addToolbarLink("cancel", "admin.php?op=$module_name");
	$tb->addToolbarLink("cpanel", "admin.php?op=$module_name");	
	
	$post_error_msg = false;
	$post_error_msg = mxSessionGetVar('stc_upload_error');
	if($post_error_msg){			
		$msga = '<div class="warning">';
		$msga .='<div style="text-align: left;"><h3>' . _stc_ERROR . '</h3><strong>' . _stc_ERROR_NOWRITE . '</strong><ul><li>' . implode('</li><li>', $post_error_msg) . '</li></ul></div>';
		$msga .='</div><div>&nbsp;</div>';
		$tb->add("", "html",$msga);
		mxSessionDelVar('stc_upload_error');
	}
	
	$tb->addFieldSet("before", _stc_INTRO,'',false);
	$tb->add("before", "input", "show_name", $stc_config['show_name'], _stc_MODNAME, _stc_MODNAME_HELP, 30);
	$tb->add("before", "editor", "show_before", $stc_config['show_before'], _stc_INTRO, "", 200,true,true);
	
	$tb->addFieldSet("design", _stc_DESIGN,'',false);
	$tb->add("design", "select", "show_design", $stc_config['show_design'] , _stc_DESIGN_SELECT, _stc_DESIGN_SELECT_HELP,1, $designselector,"style='width:85%'");
	$tb->add("design", "yesno", "show_accordion", $stc_config['show_accordion'], _stc_ACCORDION, _stc_ACCORDION_HELP,'','style="width:30%; text-align:center"');
	$tb->add("design", "yesno", "show_details", $stc_config['show_details'], _stc_DETAILS, _stc_DETAILS_HELP,'','style="width:30%; text-align:center"');
	
	$tb->add("design", "yesno", "show_blocks", $stc_config['show_blocks'], _stc_BLOCKS, '','','style="width:30%; text-align:center"');
 	 
	$tb->addFieldSet("system", _stc_SYSTEM,'',false); 
	$tb->add("system", "yesno", "show_welcome", $stc_config['show_welcome'],_stc_WELCOMEBOX, _stc_WELCOMEBOX_HELP,'','style="width:30%; text-align:center"');
	$tb->add("system", "yesno", "image_upload", $stc_config['image_upload'], _stc_UPLOAD_ALLOW, '','','style="width:30%; text-align:center"');

	$tb->add("system", "warning",$msg);
	$tb->add("system","html","<div>&nbsp;</div>");
	
	$tb->add("system", "input", "upload_path", $stc_config['upload_path'], '' . _stc_UPLOAD . ' '.$checkdir.'', '', 30);
	// zwei inputs bauen
	$nase = '<div><input type="text" style="width:15%; text-align:center" name="upload_width" value="' . $stc_config['upload_width'] . '" required="required"> ' . _stc_UPLOAD_SIZE_WIDTH . '</div><div> <input type="text" style="width:15%; text-align:center" name="upload_hight" value="' . $stc_config['upload_hight'] . '" required="required"> ' . _stc_UPLOAD_SIZE_HIGHT . ' </div>';
	
	$tb->add("system","special",'',$nase, _stc_UPLOAD_SIZE,  _stc_UPLOAD_SIZE_HELP);
	$tb->add("system","html","<div>&nbsp;</div>");
	$tb->add("system", "warning",$sys_msg);
	$tb->add("system", "yesno", "user_system", $stc_config['user_system'], _stc_INFO_USER_PMX, '','','style="width:30%; text-align:center"');
	$tb->add("system", "yesno", "user_edit_data", $stc_config['user_edit_data'], _stc_USERDATA, '','','style="width:30%; text-align:center"');
	$tb->add("system", "yesno", "user_editor", $stc_config['user_editor'], _stc_WYSIWYG, _stc_WYSIWYG_HELP,'','style="width:30%; text-align:center"');

	$form=$tb->Show();
	unset ($tb);
	
	/*
     * Template
     */
    $template = load_class('Template');
    $template->init_path(__FILE__);	
    
	// Template Design
	$show_template = $stc_config['show_design'];
	
    /* hier die Ausgabefelder angeben */
    $template->assign(compact('form'));
    
	mxIncludeHeader();;
		$template->display("admin/main.html");
	mxIncludeFooter();
}

/***
* 
*
***/
function stcCategorys(){
	global $prefix, $module_name;

	$config = load_class('Config',$module_name);
	load_class('AdminForm');
	
	$redirect=true;		
	
	// mal die Sortierung gerade ziehen
	stcRepairSortCategorys();	
	
	mxSessionDelVar('stc_box');	
	// AdminForm laden
	$tb = load_class('AdminForm', "adminFormMain");
	$redirect=true;
// Auswertung von Klickfunktion
	switch (pmxAdminForm::CheckButton()) {
		case "sort_categorys":
			stcSortingCategorys($_POST);
			break;
			
		case "add":
			stcCategorysContent();
			exit;
			break;
		case "publish":
			stcPublishCategorys();
			break;
					
		case "unpublish":
			stcUnPublishCategorys();
			break;
			
		case "edit":
			stcEditCategorysAll();
			break;

		case "delete":
			stcShowDeleteCategorys();
			break;
			
		case "config":
			stcSettings();
			exit;
			break;
			
		default:
        break;
	}	
	
	// Config laden
	$stc_config=$config->get();
	
	// alle Kategorien auslesens
	$result = sql_query("SELECT cat_id, cat_active, cat_name, cat_counter, cat_sorting FROM " . $prefix . "_structure_category order by cat_sorting asc");
	$count = sql_num_rows($result);	

	
	$tb->__set('title','' . imgModul() . ' ' . _stc_STRUCTURE . ' ' . _stc_BOX . '');
	$tb->__set('description',"");
    $tb->__set("tb_text", "");
    $tb->__set("tb_direction", 'right');
    $tb->__set("infobutton", true);
    $tb->__set("tb_pic_heigth", 22);
    $tb->__set("cssclass", "toolbar1");
    $tb->__set('acceptbutton', false);
    $tb->__set('homelink', false);
    $tb->__set('target_url', "admin.php?op=" . $module_name . "&act=categorys");

	$tb->__set('tb_pic_alternate_path',"modules/$module_name/images/adminform/"); 

    if($count > "1"){
    	$tb->addToolbar("sort_categorys", _stc_SORT,'sort_zahl', _stc_SORT_HELP);
   	}
   	if($count == "1"){
	   	$unsorting = ';cursor:not-allowed;" readonly="readonly"';

   	}else{
	   	$unsorting = '"';
   	}

	$tb->addToolbar("add");	
	$tb->addToolbar("editx");
	$tb->addToolbar("publishX");
	$tb->addToolbar("unpublishX");
	$tb->addToolbar("deleteX");
	$tb->addToolbarSpace();

	$tb->addToolbarLink("cpanel", "admin.php?op=$module_name");	
	$table = '<table class="list" width="100%">
				<thead> 
					<tr> 
						<th width="15" align="center"><input type="checkbox" name="toggle" value="" onclick="checkAll(' . $count . ');" /></th> 
						<th style="text-align:center; width:10%" >' . _stc_SORT . '</th> 
						<th width="*">' . _stc_TITLE . '</th>
						<th width="80" style="text-align:center">' . _stc_PUBLISH . '</th>
						<th width="30" style="text-align:center">' . _stc_COUNTER . '</th>
						<th width="50" style="text-align:center">&nbsp;</th>
					</tr>
				</thead> 
				<tbody>';
				
	// setzen von CCS Klassen und Icon
	$colClass = array("alternate","alternate-b");
	$a = count($colClass);
	$i ='0';
	$image_dir = "modules/$module_name/images";
	$edit_icon = '<img title="' . _stc_EDIT . '" src="' . $image_dir . '/edit.gif" style="width:15px" alt="" />';
	
	$active_icon = '<img title="' . _stc_DEACTIVE . '" src="images/adminform/accept.png" style="width:15px" alt="" />';
	$deactive_icon = '<img title="' . _stc_ACTIVE . '" src="images/adminform/delete.png" style="width:15px" alt="" />';
	
	while(list($cat_id, $cat_active, $cat_name, $cat_counter, $cat_sorting) = sql_fetch_row($result)){
		
		// aktiviert oder deaktiviert
		switch ($cat_active){
			case "0":
			$viewstatus = '<a href="admin.php?op=' . $module_name . '&act=category_activate&what=1&cid=' . $cat_id . '">' . $deactive_icon . '</a>';
			break;
			
			case "1":
				$viewstatus = '<a href="admin.php?op=' . $module_name . '&act=category_deactivate&what=0&cid=' . $cat_id . '">' . $active_icon . '</a>';
				
			break;

		}
		// delete Icon vorbereiten
		switch ($cat_counter){
			case "0":
			$delete_icon = '<a href="admin.php?op=' . $module_name . '&act=category_delete_force&pvs=' . $cat_id . '"><img title="' . _stc_QUICK_DELETE . '" src="images/delete.gif" style="width:15px" alt="" /></a>';
			break;
			
			default:
			$delete_icon = '<img title="' . _stc_QUICK_NODELETE . '" src="modules/' . $module_name . '/images/nodelete.gif" style="width:15px" alt="" />';
			break;
		}
		
		$table .= '<tr class="' . $colClass[$a%count($colClass)] . '">
					<td class="align-center"><input type="checkbox" id="cb'.$i.'" name="cid[]" value="' . $cat_id . '" onclick="isChecked(this.checked);"/></td> 
					<td style="text-align:center"> <input type="text"  value="' . $cat_sorting . '" name="sort_id[' . $cat_id . ']" style="width:50%;text-align:center' . $unsorting . '></td>
					<td><a href="admin.php?op=' . $module_name . '&act=content&box=' . $cat_id . '">' . $cat_name . '</a></td>
					<td style="text-align:center">' . $viewstatus . '</td>
					<td style="text-align:center">'.$cat_counter.'</td>
					<td style="text-align:center"><a href="admin.php?op=' . $module_name . '&act=add_categorys&insertid=' . $cat_id . '">' . $edit_icon . '</a> ' . $delete_icon . '</td>
				</tr>';	
		$i++;
		$a++;
	}		
		
	$table .= '</table>';
	$tb->add ("",'html',$table);	
	
	// Anzeige Legende
	$icon_dir = 'modules/' . $module_name . '/images';
	$icon_delete = '<img title="' . _stc_QUICK_DELETE . '" src="' . $icon_dir . '/delete.gif">';
	$icon_no_delete = '<img title="' . _stc_QUICK_NODELETE . '" src="' . $icon_dir . '/nodelete.gif">';
	$icon_edit ='<img title="' . _stc_EDIT . '" src="' . $icon_dir . '/edit.gif">';
	$legende = '' . $icon_delete . ' ' . _stc_LEGENDE_DELETE . '  ' . $icon_no_delete . ' ' . _stc_LEGENDE_NODELETE . '  ' . $icon_edit . ' ' . _stc_LEGENDE_EDIT . '';
	
	$tb->add("","html", $legende);
	
	$form=$tb->Show();
	unset($tb);
	
	/*
     * Template
     */
    $template = load_class('Template');
    $template->init_path(__FILE__);	
	$error=isset($error)?$error:"";	
	/* hier die Ausgabefelder angeben */
	$template->assign(compact('form','error','module_name'));	

	include_once('header.php');	
		echo $form;
		#$template->display("admin.html");
	include_once('footer.php');		
}



/***
* stcCategorysContent()
* anlegen von neuer Kategorie
***/
function stcCategorysContent(){
	global $prefix, $module_name;

	$config = load_class('Config',$module_name);
	load_class('AdminForm');
		
	$redirect=true;		
		
	// default Werte laden
	$newcategory = defaultNewCategory();
	
	if(isset($_GET['insertid'])){
		$insertid = $_GET['insertid'];
	}else{
		if(!isset($_POST['insertid'])){
			$insertid = $newcategory['insertid'];
		}else{
			$insertid = $_POST['insertid'];
		}
	}

	// Auswertung von Klickfunktion
	switch (pmxAdminForm::CheckButton()) {
		case "accept":
		$redirect=false;
		
		case "save":
			$pvs = mxAddSlashesForSQL($_POST);
			extract($pvs);
			$new_category = cleanWhitespace($new_category);
			$category_status = intval($category_status);
	
			if($insertid > "0"){
				$qry = "update " . $prefix . "_structure_category set cat_name = '$new_category', cat_active = '$category_status' where cat_id = '$insertid'";
				$result = sql_query($qry);
			}else{	
				if(!empty($new_category)){
					$sqla = "INSERT INTO " . $prefix . "_structure_category ( cat_id, cat_active, cat_counter, cat_name, cat_sorting ) VALUES ('', '$category_status','0','$new_category', '999')";
					$resulta = sql_query($sqla);
					$insertid = sql_insert_id();
					stcRepairSortCategorys();
				}
			}	

			if($redirect){
				mxRedirect("admin.php?op=$module_name&act=categorys", _CHANGESAREOK, 1);
			}
						
		break;
		
	    default:
        break;
	}	

	// Config laden
	$stc_config=$config->get();
		
	if($insertid > "0"){
		$result = sql_query("SELECT cat_name, cat_active FROM " . $prefix . "_structure_category where cat_id='$insertid'");
		list( $cat_name, $cat_status) = sql_fetch_row($result);
			$newcategory = array('name'=>$cat_name, 'status'=>$cat_status);
	}

	$tb = new pmxAdminForm("Main");	

	$tb->__set('title', '' . imgModul() . '  ' . _stc_STRUCTURE . ' - ' . _stc_CATEGORYS . '' );
	$tb->__set('description', '');
    $tb->__set("tb_pic_heigth", 22);
    $tb->__set("homelink", false);	
    $tb->__set("infobutton", true);
    $tb->__set('target_url', "admin.php?op=" . $module_name . "&act=add_categorys");

	$tb->addToolbar("accept");
	$tb->addToolbar("save");
	$tb->addToolbarSpace();
	$tb->addToolbarLink("cancel", "admin.php?op=$module_name&act=categorys");

	// Neue Kategorie anlegen
	$tb->addFieldSet("add_category", _stc_CATEGORYS,"",false);
	$tb->add("add_category", "input", "new_category", $newcategory['name'], _stc_TITLE, '', 30, "placeholder='" . _stc_BOX . "' required='required'");
	$sectionselect=array("" . _stc_ACTIVE . "" => "1","" . _stc_DEACTIVE . "" => "0");
	$tb->add("add_category", "select", "category_status", $newcategory['status'] , _stc_STATUS, '', 1, $sectionselect);
    $tb->add("", "hidden", "insertid", $insertid);

	$form=$tb->Show();
	unset ($tb);
	
	/*
     * Template
     */
    $template = load_class('Template');
    $template->init_path(__FILE__);	
    
    /* hier die Ausgabefelder angeben */
    $template->assign(compact('form'));
    
	mxIncludeHeader();;
		$template->display("admin/main.html");
	mxIncludeFooter();
}


/***
* stcShowDeleteCategorys()
* Sicherheitsabfrage Löschen Kategorien
***/
function stcShowDeleteCategorys(){	
	global $prefix, $module_name;

	//vars
	if(empty($nocheckbox)) $nocheckbox = '';
	load_class('AdminForm');
	
	$redirect=true;		

	// Auswertung von Klickfunktion
	switch (pmxAdminForm::CheckButton()) {
		case "categorys_delete_now":
			$pvs = mxAddSlashesForSQL($_POST);
			stcDeleteCategorys($pvs);	
			header("Location: admin.php?op=$module_name&act=categorys");
			break;
			
	    default:
        break;
	}	

	$count = count($_POST['cid']);
	
	$tb = new pmxAdminForm("adminFormMain");
	
	$tb->__set('title','' . imgModul() . '  ' . _stc_STRUCTURE . ' - ' . _stc_BOX . '');
	$tb->__set('description',"");
	$tb->__set("infobutton", true);
	$tb->__set('homelink', true);
    $tb->__set("tb_pic_heigth", 22);
	$tb->__set('target_url', "admin.php?op=" . $module_name . "&act=categorys_delete");	
	
	$tb->addToolbarLink("cancel", "admin.php?op=$module_name&act=categorys");
	
	$del_table = '<script type="text/javascript">checkAll('.$count.');</script>
				<div style="display:block;text-align:center" class="warning">' . _stc_CATEGORYS_DELETE_WARNING . '</div>
					<table class="list" width="100%">
					 	<thead> 
					 		<tr> 
					 			<th width="15" align="center">#</th> 
					 			<th width="35" >ID</th> 
					 			<th width="auto">' . _stc_TITLE . '</th> 
					 		</tr> 
					 	</thead> 
					 <tbody>'; 

  	// setzen von CCS Klassen
	$colClass = array("alternate","alternate-b");
	$a = count($colClass);
	$i ='0';
	$a='0';
	
	foreach($_POST['cid'] as $key => $value ){
	
		$result = sql_query("SELECT cat_name, cat_counter FROM " . $prefix . "_structure_category where cat_id='$value'");
		list($cat_name, $cat_counter) = sql_fetch_row($result);
		$checkbox = '<input type="checkbox" id="cb'.$a.'" checked="checked" name="cid[]" value="'.$value.'" onclick="isChecked(this.checked);" />';	
		
		if($cat_counter >= "1"){
			$checkbox = '<img src="modules/' . $module_name . '/images/nodelete.gif">';
			$nocheckbox = $checkbox;
		}
		
		$del_table .= '<tr class="' . $colClass[$i%count($colClass)] . '">';
			$del_table .= '<td>' . $checkbox . '</td>';
			$del_table .= '<td>' . $value . '</td>';
			$del_table .= '<td>' . $cat_name . '</td>';
		$del_table .= '</tr>';
		$i++;
	}

	$del_table .='</table>';
	$del_table .= '<div style="display:block;text-align:center"><button type="submit" name="toolbarsubmit" value="categorys_delete_now" title="delete" onclick="javascript:hideMainMenu();" >' . _stc_BUTTON_DELETE . '</button></div>
';
	
	$tb->add ("",'html',$del_table);
	$tb->add('','html', '<img src="modules/' . $module_name . '/images/nodelete.gif"> ' . _stc_LEGENDE_NODELETE . '');	

	$form=$tb->Show();
	unset ($tb);
	
	/*
     * Template
     */
    $template = load_class('Template');
    $template->init_path(__FILE__);	
    
    /* hier die Ausgabefelder angeben */
    $template->assign(compact('form'));
    
	mxIncludeHeader();;
		$template->display("admin/main.html");
	mxIncludeFooter();

}


/***
* stcEditCategorysAll
* 
***/
function stcEditCategorysAll(){
	global $prefix, $module_name;

	load_class('AdminForm');
	#mxDebugFuncVars( $_POST );
	$redirect=true;		

	// Auswertung von Klickfunktion
	switch (pmxAdminForm::CheckButton()) {
		case"accept":
			$redirect =false;
			
		case "save":
			
			$pvs = mxAddSlashesForSQL($_POST);	
			stcEditCategorysAllSave($pvs);
		
		if($redirect){
			header("Location: admin.php?op=$module_name&act=categorys");
		}
		break;
					
	    default:
        break;
	}	
	
	$cid = $_POST['cid'];	
	
	$tb = new pmxAdminForm("adminFormMain");
	$tb->__set('target_url', "admin.php?op=" . $module_name . "&act=category_edit_all");
	$tb->__set('title','' . imgModul() . '  ' . _stc_STRUCTURE . ' - ' . _stc_CATEGORYS . '');
    $tb->__set("homelink", false);	
    $tb->__set("infobutton", true);
    $tb->__set("tb_pic_heigth", 22);	
	$tb->addToolbar("accept");
	$tb->addToolbar("save");
	$tb->addToolbarSpace();
	$tb->addToolbarLink("cancel", "admin.php?op=$module_name&act=categorys");
	
	$table = '<table class="list" width="100%">
				<thead> 
					<tr> 
						<th width="30" style="text-align:center">ID</th> 
						<th width="*">' . _stc_TITLE . '</th>
						<th width="130" style="text-align:center">' . _stc_PUBLISH . '</th>  
						<th width="30" style="text-align:center">' . _stc_COUNTER . '</th>  
					</tr>
				</thead> 
				<tbody>';
    
	// setzen von CCS Klassen
	$colClass = array("alternate","alternate-b");
	$a = count($colClass);
	$i ='0';
		
	foreach ($cid as $key => $value){ 
		// mal alle Kategorien holen
		$result = sql_query("SELECT cat_id, cat_name, cat_counter, cat_active FROM " . $prefix . "_structure_category where cat_id='$value'");
		list($cat_id, $cat_name, $cat_counter, $cat_status) = sql_fetch_row($result);
					
		$table .= '<tr class="' . $colClass[$a%count($colClass)] . '">     
					<td style="text-align:center">'.$cat_id.'<input type="hidden" name="cid[]" value="'.$value.'" /></td>
				    <td><input type="text" value="' . $cat_name . '" name="cat_name['.$cat_id.']" style="width:30%"></td>
				    <td style="text-align:center">' . ShowSelectStatus($cat_id, $cat_status) . '</td>
				    <td style="text-align:center">'.$cat_counter.'</td>
				</tr>';
		$i++;
		$a++;
	}

	$table .= '</tbody></table>';
	$tb->add("", "html", $table);
	
		
	
	$form=$tb->Show();
	unset($tb);
	/*
     * Template
     */
    $template = load_class('Template');
    $template->init_path(__FILE__);	
    
    /* hier die Ausgabefelder angeben */
    $template->assign(compact('form'));
    	
	mxIncludeHeader();;
		$template->display("admin/main.html");
	mxIncludeFooter();

}


/***
* stcContents()
* Uebersicht aller Inhalte zur Kategorie
***/
function stcContent(){
	global $prefix, $module_name;

	load_class('AdminForm');
	
	// vars
	if(empty($caution_text)) $caution_text = '';
	$achtung_icon = '<img src="images/debugmode_small.png" width="13px">';
	$edit_icon = '<img title="' . _stc_EDIT . '"src="images/edit.gif" style="width:15px" alt="" />';
	
	$no_is_not_activate = '<img title="' . _stc_NOTRELEASE . '" src="modules/' . $module_name . '/images/nostatus_off.png" style="width:18px" alt="" />';
	$caution_text = '' . $achtung_icon . '  ' . _stc_USEREDIT_WARN . '';
	$no_is_not_activate_text ='' . $no_is_not_activate . ' ' . _stc_NOTRELEASE . '';
	
	$categoryid = mxSessionGetVar('stc_box');
	$redirect=true;		

	// Auswertung von Klickfunktion
	switch (pmxAdminForm::CheckButton()) {
		case "add":
			stcShowContent();
			exit;
			break;
		
		case "delete":
			stcShowDeleteContent($_POST);
			exit;
			break;
			
		case "move":
			stcMoveContent();
			exit;
			break;
				
		case "copyto":
			stcCopyContent();
			break;
		
							
	    default:
        break;
	}	
	
	$tb = new pmxAdminForm("adminFormMain");	
	
	$tb->__set('target_url', "admin.php?op=" . $module_name . "&act=content");
	$tb->__set('title','' . imgModul() . '  ' . _stc_STRUCTURE . ' - ' . _stc_CATEGORYS . '');
    $tb->__set("homelink", false);	
    $tb->__set("infobutton", true);
	$tb->__set("tb_pic_heigth", 22);
	

	$result = sql_query("SELECT * FROM " . $prefix . "_structure_content where con_category=$categoryid");
	$count = sql_num_rows($result);


	$tb->addToolbar("add");	

	if($count >= 1){
		$tb->addToolbar("moveX", _MOVE, "move_to_folder");
		$tb->addToolbar("copytox", _COPY,'move');
		$tb->addToolbar("deleteX");
	}
	$tb->addToolbarSpace();
	$tb->addToolbarLink("cpanel", "admin.php?op=$module_name&amp;act=categorys", 'Box Menu');

	
	/* */
	$table ='<table class="full list" width="100%">
			 	<tr>
					<th style="width:5%"><input type="checkbox" name="toggle" value="" onclick="checkAll(' . $count . ');" /></th>
					<th style="width:25%">' . _stc_TITLE . '</th>
					<th style="width:50%">' . _stc_DESCIPTION . ' ' . _stc_DESCIPTION_SHORT . '</th>
					<th style="width:10%; text-align:center">' . _stc_PUBLISH . '</th>
					<th style="width5%">&nbsp;</th>
				</tr>';	

	// setzen von CCS Klassen
	$colClass = array("alternate","alternate-b");
	$a = count($colClass);
	$i ='0';
	while ($zeile = sql_fetch_array( $result)){		
		$caution_icon = '';

		/*  jetzt in Temp schauen ob dort Content mit Usernamen vorhanden ist
			falls ja zeige den temp an */
		$result_tmp = sql_query("SELECT * FROM " . $prefix . "_structure_content_temp where con_owner='".$zeile['con_owner']."'");
		$count_tmp = sql_num_rows($result_tmp);	
		
		if($count_tmp > 0){
			// User hat Daten geaendert, Icon anpassen
			$caution_icon = $achtung_icon;
			
			// mit TMP Daten ueberschreiben
			$zeile = sql_fetch_array( $result_tmp);
		}
		
		// aktiviert oder deaktiviert
		$is_not_activate = '<img title="' . _stc_ACTIVE . '"  title="" src="modules/' . $module_name . '/images/status_off.png" style="width:18px" alt="" />';
		$is_activate = '<img title="' . _stc_DEACTIVE . '"  src="modules/' . $module_name . '/images/status_on.png" style="width:18px" alt="" />';
		
		switch ($zeile['con_active']){
			
			case "0":
				$view_active = '<a href="admin.php?op=' . $module_name . '&act=content_activate&what=1&cid=' . $zeile['con_id']	. '&cat_id=' . $categoryid . '">' . $is_not_activate . '</a>';
				break;
			
			case "1":
				$view_active = '<a href="admin.php?op=' . $module_name . '&act=content_activate&what=0&cid=' . $zeile['con_id'] . '&cat_id=' . $categoryid . '">' . $is_activate . '</a>';
				break;
			case "9":
				$view_active = '<a href="#">' . $no_is_not_activate . '</a>';
				
				break;
		}
		
		/* Text verkuerzen */
		$zeile['con_desc'] = mxStripSlashes($zeile['con_desc']);
		$zeile['con_desc'] = mxCutString($zeile['con_desc'], $len = '120', $add = "...", $cutter = " ");	
		
		$table .= '<tr class="' . $colClass[$a%count($colClass)] . '">'
					.'<td><input type="checkbox" id="cb' . $i . '" name="cid[]" value="' . $zeile['con_id'] . '" onclick="isChecked(this.checked);" /></td>'
					.'<td>'.$caution_icon.' <a href="admin.php?op=' . $module_name . '&act=content_show&insertid=' . $zeile['con_id'] . '">'. $zeile['con_title'] . '</a></td>'
					.'<td>'. $zeile['con_desc'] . '</td>'
					.'<td style="text-align:center">'. $view_active . '</td>'
					.'<td><a href="admin.php?op=' . $module_name . '&act=content_show&insertid=' . $zeile['con_id'] . '">' . $edit_icon . '</a></td>'
				.'</tr>';
		$i++;
		$a++;
	}				
				
	$table .= '</table>';	
			
	$tb->add ("",'html',$table);
	
	$tb->add("","html", ''. $caution_text . ' ' . $no_is_not_activate_text . '');
	$tb->add("", "hidden", "box", $categoryid);

	$form=$tb->Show();
	unset($tb);
	/*
     * Template
     */
    $template = load_class('Template');
    $template->init_path(__FILE__);	
    
    /* hier die Ausgabefelder angeben */
    $template->assign(compact('form'));
    
	mxIncludeHeader();;
		$template->display("admin/main.html");
	mxIncludeFooter();
	
}


/***
* stcContent()
* anlegen bearbeiten von Inhalt
***/
function stcShowContent(){
	global $prefix, $module_name;
	pmxHeader::add_style("modules/$module_name/style/style.css");

	$config = load_class('Config',$module_name);	
	load_class('AdminForm');	
	
	$content = defaultNewContent();

	if(!isset($_POST['insertid'])){
		$insertid = $content['insert_id'];
	}
	
	if(isset($_GET['insertid'])){
		$insertid = $_GET['insertid'];
	}	
		
	$box = mxSessionGetVar('stc_box');
	
	// komme vom Start
	if(isset($_GET['box'])){
		$box = intval($_GET['box']);
	}
		
	// hier laden da es in der Klickfunktion gebraucht wird
	$stc_config=$config->get();

	$redirect=true;	
	// Auswertung von Klickfunktion
	switch (pmxAdminForm::CheckButton()) {
		case "accept":
			$redirect=false;
		
		case "save";
			$pvs = mxAddSlashesForSQL($_POST);
			extract($pvs);

			// vars behandeln
			$title = cleanWhitespace($title);
			$function = cleanWhitespace($function);
			$owner = cleanWhitespace($owner);
			$active = intval($active);
			$box = intval($box);
			$upload_path = 'modules/' . $module_name . '/' . $stc_config['upload_path']. '';
			$updateimg = '';
			
			// speichern in DB, da $insert = 0
			if($insertid == "0"){
				
				// in DB stecken
				$sqla = "INSERT INTO " . $prefix . "_structure_content ( con_id, con_active, con_category, con_owner, con_title, con_desc,  con_function ) VALUES ('', '$active', '$box', '$owner', '$title', '$desc', '$function')";
				$resulta = sql_query($sqla);
				$insertid = sql_insert_id();
				
				/* auf Bild testen Start */
				if (array_key_exists('content_imgage',$_FILES)) {
					$checkupload = $_FILES['content_imgage']['name']['0'];
					$checkerror  = $_FILES['content_imgage']['error']['0'];
				}
				// // jetzt Bild verarbeiten
				if(!empty($checkupload) and ($checkerror == "0")){	
					$checkupload = renameImgorDir( $checkupload );	
					$checkupload = '__' . $insertid . '__' . $checkupload . '';
					$tmp_bild = $_FILES['content_imgage']['tmp_name']['0'];
					move_uploaded_file($tmp_bild, "$upload_path/$checkupload") ;
					stcImageChangeSize($checkupload);
				}
				/* Ende Bild */
				
				// jetzt nochmal schnell Bild ID aendern
				if(!empty($checkupload)){
					$my_hash = md5(file_get_contents( "$upload_path/$checkupload" ));
					$qry = "update ${prefix}_structure_content set con_image = '$checkupload', con_hash= '$my_hash' where con_id=$insertid";
					sql_query($qry);
				}
				
				// Counter updaten
				sql_query("update " . $prefix . "_structure_category cat_counter set cat_counter = cat_counter + 1 where cat_id='$box'");
			}else{
				// da $insertid ja gesetzt ist, jetzt updaten
				
				/* auf Bild testen Start */
				if (array_key_exists('content_imgage',$_FILES)) {
					$checkupload = $_FILES['content_imgage']['name']['0'];
					$checkerror  = $_FILES['content_imgage']['error']['0'];
				}
				// // jetzt Bild verarbeiten
				if(!empty($checkupload) and ($checkerror == "0")){	
					
					$checkupload = renameImgorDir( $checkupload );			
					$tmp_bild = $_FILES['content_imgage']['tmp_name']['0'];
					$checkupload = '__' . $insertid . '__' . $checkupload . '';
					move_uploaded_file($tmp_bild, "$upload_path/$checkupload") ;
					stcImageChangeSize($checkupload);
					
					/* Ende Bild */
									
					// ist den ein altes Bild vorhanden, loesche nur wenn neues mit kommt
					if(!empty($checkupload)){
						$result = sql_query("SELECT con_image FROM " . $prefix . "_structure_content where con_id='$insertid'");
						list($old_img) = sql_fetch_row($result);
						if(!empty($con_img)){
							// altes Bild loeschen
							$image_delete = '' . $upload_path . '/' . $old_img . '';
							unlink($image_delete);
						}
					}
					// Updaten des Bildes
					$my_hash = md5(file_get_contents( "$upload_path/$checkupload" ));
					sql_query("update " . $prefix . "_structure_content set con_image = '$checkupload', con_hash='$my_hash' where con_id='$insertid'");
				}
				
				// ist altes Bild noch da
				$result_img_old = sql_query("SELECT  con_image, con_hash FROM " . $prefix . "_structure_content where con_owner ='$owner'");
				list( $con_image_old, $con_hash_old) = sql_fetch_row($result_img_old);
				
				if(!empty($con_image_old)){
					$updateimg = ",con_image = '".$con_image_old."', con_hash = '".$con_hash_old."'";
				}				
			
				// ist Tempbild vorhanden
				$result_tmp_img = sql_query("SELECT  con_image, con_hash FROM " . $prefix . "_structure_content_temp where con_owner ='$owner'");
				list( $con_image_tmp, $con_hash_tmp) = sql_fetch_row($result_tmp_img);	
				
				if(!empty($con_image_tmp)){
					$teile = explode("__", $con_image_tmp, 2);
					#mxDebugFuncVars( $teile );
					$nowimg = $teile['1'];
					//update var
					$updateimg = ",con_image = '".$nowimg."', con_hash = '".$con_hash_tmp."'";
					
					$is_img = mxSessionGetVar('stc_image');
					if(empty($is_img)){
					
						rename ( "$upload_path/$con_image_tmp" , "$upload_path/$nowimg" );
						if(!empty($con_image_old)){
							unlink("$upload_path/$con_image_old");
						}
						// kontrolle
						mxSessionSetVar('stc_image', '1');
					}

				}

				// kommt ich aus Temp DB
				$is_out_temp = mxSessionGetVar('stc_temp_db');
				if(!empty($is_out_temp)){
					$qry = "delete from " . $prefix . "_structure_content_temp where con_id ='$insertid'";
					$result = sql_query($qry); 
				}
				
				// in DB stecken
				sql_query("update " . $prefix . "_structure_content set 
					con_active = '$active',
					con_title = '$title',
					con_function = '$function',
					con_owner = '$owner',
					con_desc = '$desc'
					" . $updateimg . "
				where con_id='$insertid'");  
					
			}
			
			mxSessionDelVar('stc_temp_db');	
						
			if($redirect){
				mxSessionDelVar('stc_image');
				mxRedirect("admin.php?op=$module_name&act=content&box=$box", _CHANGESAREOK, 1);
			}				
		break;
		
	    default:
        break;
	}	
	
	
	if($insertid > "0"){
		
		$result__temp = sql_query("SELECT con_title, con_active, con_function, con_owner, con_desc, con_image FROM " . $prefix . "_structure_content_temp where con_id='$insertid'");
		$count__temp = sql_num_rows($result__temp);
		
		$result = sql_query("SELECT con_title, con_active, con_function, con_owner, con_desc, con_image FROM " . $prefix . "_structure_content where con_id='$insertid'");
		if($count__temp >= 1){
			mxSessionSetVar('stc_temp_db', '1');
			$which_db = $result__temp;
		}else{
			$which_db = $result;
		}
		list( $con_name, $con_active, $con_function, $con_owner, $con_desc, $con_img) = sql_fetch_row($which_db);
			$content['title'] = $con_name;
			$content['active'] = $con_active;
			$content['function'] = $con_function;
			$content['owner'] = $con_owner;
			$content['desc'] = $con_desc;
			$content['content_imgage'] = $con_img;		
	}
	// ueberschreiben, da noch die 9 drin ist
	if($content['active'] == "9"){
		$content['active'] = 0;
	}
	$tb = load_class('AdminForm', "EditCategory");

	$tb->__set('target_url', "admin.php?op=" . $module_name . "&act=content_show");
	$tb->__set('title','' . imgModul() . '  ' . _stc_STRUCTURE . ' - ' . _stc_CONTENT . '');
    $tb->__set("tb_pic_heigth", 22);
    $tb->__set("homelink", false);	
    $tb->__set("infobutton", true);
	
	$tb->addToolbar("accept");
	$tb->addToolbar("save");
	$tb->addToolbarSpace();
	$tb->addToolbarLink("cancel", "admin.php?op=$module_name&act=content&box=$box");
	
	$tb->addFieldSet("content",'CONTENT','',false);
	$tb->add("content", "input", "title", $content['title'], _stc_TITLE, _stc_CONTENT_TITLE_HELP, 30, "required='required'");
	$tb->add("content", "input", "function", $content['function'], _stc_FUNCTION, '' . _stc_CONTENT_FUNCTION_HELP . '' . _stc_INFO. '', 30);
	
	if($stc_config['user_system'] == "1"){	
		$tb->add("content", "input", "owner", $content['owner'], _stc_OWNER, '' . _stc_INFO. '', 30);
	}else{
		$tb->add("content", "hidden", "owner", '');

	}
	$tb->add("content", "editor", "desc", $content['desc'], _stc_DESCIPTION, "", 200,true,true);

	// Upload nur anzeigen wenn erlaubt
	if($stc_config['image_upload'] == "1"){
		$img_desc = ''._stc_CONTENT_PIC.'';
		
		// Bildanzeigen
		$show_img = '<img class="usertab" src="modules/' . $module_name . '/images/place_holder_m.png">';
		if(!empty($content['content_imgage'])){
 			
			$show_img = '<a href="modules/' . $module_name . '/' . $stc_config['upload_path'] . '/' . $content['content_imgage'] . '" rel="pretty"><img class="" src="modules/' . $module_name . '/' . $stc_config['upload_path'] . '/' . $content['content_imgage'] . '" style="width:10em"></a><br><a class="button" href="admin.php?op='.$module_name.'&act=delete_image&insertid='.$insertid.'&box='.$box.'&image='.$content['content_imgage'].'">' . _stc_DELETE_IMAGE . '</a>';
		}
		
		$img_desc .= '<br>' . $show_img . '';
		$tb->add("content", "file","content_imgage", "" , $img_desc, '',"");
	}
	
	$sectionselect=array("" . _stc_ACTIVE . "" => "1","" . _stc_DEACTIVE . "" => "0");
	$tb->add("content", "select", "active", $content['active'] , _stc_PUBLISH, '', 2, $sectionselect);

	$tb->add("", "hidden", "box", $box);
	$tb->add("", "hidden", "insertid", $insertid);

	$form=$tb->Show();
	unset($tb);
	
	/*
     * Template
     */
    $template = load_class('Template');
    $template->init_path(__FILE__);	
    
    /* hier die Ausgabefelder angeben */
    $template->assign(compact('form'));
    
	mxIncludeHeader();;
		$template->display("admin/main.html");
	mxIncludeFooter();
	
}


/***
* stcShowDeleteContent()
* Content loeschen
***/
function stcShowDeleteContent(){
	global $prefix, $module_name;

	$config = load_class('Config',$module_name);	
	load_class('AdminForm');
			
	$redirect=true;		

	// Funktionen einbinden
	include_once(PMX_MODULES_DIR . DS . $module_name . DS . "includes/functions.php");
	include_once(PMX_MODULES_DIR . DS . $module_name . DS . "includes/db.functions.php");	
	include_once(PMX_MODULES_DIR . DS . $module_name . DS . "includes/default_config.php");	
	
	// Auswertung von Klickfunktion
	switch (pmxAdminForm::CheckButton()) {
		case "content_delete_now":
			$stc_config=$config->get();

			$pvs = mxAddSlashesForSQL($_POST);
			stcDeleteContents($pvs, $stc_config['upload_path']);	
			header("Location: admin.php?op=$module_name&act=content&box=" . $_POST['box'] . "");
			break;
			
	    default:
        break;
	}	
	$stc_config=$config->get();
	$count = $_POST['boxchecked'];
	
	$tb = new pmxAdminForm("adminFormMain");
	
	$tb->__set('title','' . imgModul() . '  ' . _stc_STRUCTURE . ' - ' . _stc_BOX . '');
	$tb->__set('description',"");
	$tb->__set("infobutton", true);
	$tb->__set('homelink', true);
	$tb->__set("tb_pic_heigth", 22);
	$tb->__set('target_url', "admin.php?op=" . $module_name . "&act=content_delete");
	
	$tb->addToolbarLink("cancel", "admin.php?op=$module_name&act=content&box=" . $_POST['box'] . "");
	 
	$del_table = '<script type="text/javascript">checkAll('.$count.');</script>
				<div style="display:block;text-align:center" class="warning">' . _stc_CATEGORYS_DELETE_WARNING . '</div>
					<table class="list" width="100%">
					 	<thead> 
					 		<tr> 
					 			<th width="15" align="center">#</th> 
					 			<th width="35" >ID</th> 
					 			<th width="auto">' . _stc_TITLE . '</th> 
					 		</tr> 
					 	</thead> 
					 <tbody>'; 

  	// setzen von CCS Klassen
	$colClass = array("alternate","alternate-b");
	$a = count($colClass);
	$i ='0';
	$a='0';
	
	foreach($_POST['cid'] as $key => $value ){
		
		$result = sql_query("SELECT con_title FROM " . $prefix . "_structure_content where con_id='$value'");
		list($con_name ) = sql_fetch_row($result);
	
		$checkbox = '<input type="checkbox" id="cb'.$a.'" checked="checked" name="cid[]" value="'.$value.'" onclick="isChecked(this.checked);" />';	
	
		$del_table .= '<tr class="' . $colClass[$i%count($colClass)] . '">';
			$del_table .= '<td>' . $checkbox . '</td>';
			$del_table .= '<td>' . $value . '</td>';
			$del_table .= '<td>' . $con_name . '</td>';
		$del_table .= '</tr>';
		$i++;
	}

	$del_table .='</table>';
	$del_table .= '<div style="display:block;text-align:center"><button type="submit" name="toolbarsubmit" value="content_delete_now" title="delete" onclick="javascript:hideMainMenu();" >' . _stc_BUTTON_DELETE . '</button></div>
';
	
	$tb->add ("",'html',$del_table);	
	$tb->add("", "hidden", "box", $_POST['box']);

	$form=$tb->Show();
	unset ($tb);
	
	/*
     * Template
     */
    $template = load_class('Template');
    $template->init_path(__FILE__);	
    
    /* hier die Ausgabefelder angeben */
    $template->assign(compact('form'));
	
	mxIncludeHeader();;
		$template->display("admin/main.html");
	mxIncludeFooter();
	
}




/***
* stcMoveContent()
* verschieben von Content
***/
function stcMoveContent(){
	global $prefix, $module_name;

	$config = load_class('Config',$module_name);	
	load_class('AdminForm');
			
	$redirect=true;		

	// Funktionen einbinden
	include_once(PMX_MODULES_DIR . DS . $module_name . DS . "includes/functions.php");
	include_once(PMX_MODULES_DIR . DS . $module_name . DS . "includes/db.functions.php");	
	include_once(PMX_MODULES_DIR . DS . $module_name . DS . "includes/default_config.php");	
	
	// Auswertung von Klickfunktion
	switch (pmxAdminForm::CheckButton()) {
		case "content_move_now":
			stcContentMove();
			break;
			
	    default:
        break;
	}	
	$stc_config=$config->get();
		
	$tb = new pmxAdminForm("adminFormMain");
	$tb->__set('title','' . imgModul() . '  ' . _stc_STRUCTURE . ' - ' . _stc_BOX . '');

	$tb->__set("infobutton", false);
	$tb->__set('homelink', true);
	$tb->__set("tb_pic_heigth", 22);
	$tb->__set('target_url', "admin.php?op=" . $module_name . "&act=content_move");// &box=" . intval( $_POST['box'] ) ."
	
	//$tb->addToolbar('save');
	$tb->addToolbarLink('cancel',"admin.php?op=$module_name&act=content&box=" . intval( $_POST['box'] ) . "");	
	
	$table = '<div style="display:block;text-align:center" class="info">Markierte Artikel werden in den gewählte Kategorie verschoben. Sie können auch wieder einzelne Artikel abwählen. </div>';

	// Kategorien holen und in selectbox stecken
	$box = '<div style="text-align:center"><select name="new_box" size="10" style="width:45%; text-align: center" >';//required="required"
	
	$box .='<optgroup label="Bitte Kategorie auswählen" class="current" >';
	$resulta = sql_query("SELECT cat_id, cat_name FROM " . $prefix . "_structure_category where cat_id!= ".intval( $_POST['box'] )."");
	while(list($cat_id, $cat_name ) = sql_fetch_row($resulta)){
		$box .= '<option value="' . $cat_id . '">' . $cat_name . '</option>';
	}
	$box .= '</select></div>';
	
	$count = $_POST['boxchecked'];
	$del_table = '<script type="text/javascript">checkAll('.$count.');</script>
					<table class="list" width="100%">
					 	<thead> 
					 		<tr> 
					 			<th width="15" align="center">#</th> 
					 			<th width="35" >ID</th> 
					 			<th width="auto">' . _stc_TITLE . '</th> 
					 		</tr> 
					 	</thead> 
					 <tbody>'; 

  	// setzen von CCS Klassen
	$colClass = array("alternate","alternate-b");
	$a = count($colClass);
	$i ='0';
	$a='0';
	
	foreach($_POST['cid'] as $key => $value ){
		
		$result = sql_query("SELECT con_title FROM " . $prefix . "_structure_content where con_id='$value'");
		list($con_name ) = sql_fetch_row($result);
	
		$checkbox = '<input type="checkbox" id="cb'.$a.'" checked="checked" name="cid[]" value="'.$value.'" onclick="isChecked(this.checked);" />';	
	
		$del_table .= '<tr class="' . $colClass[$i%count($colClass)] . '">';
			$del_table .= '<td>' . $checkbox . '</td>';
			$del_table .= '<td>' . $value . '</td>';
			$del_table .= '<td>' . $con_name . '</td>';
		$del_table .= '</tr>';
		$i++;
	}
	
	$del_table .='</table>';
	
	$submit = '<div style="display:block;text-align:center"><button type="submit" name="toolbarsubmit" value="content_move_now" title="delete" onclick="javascript:hideMainMenu();" >' . _stc_BUTTON_MOVE . '</button></div>';

	$tb->add ("",'html',$table);	
	$tb->add ("",'html',$box);
	$tb->add("", 'html', $del_table);
	$tb->add ("",'html',$submit);	
	$tb->add("",'hidden','box', intval( $_POST['box'] ));

	$form=$tb->Show();
	unset ($tb);
	
	/*
     * Template
     */
    $template = load_class('Template');
    $template->init_path(__FILE__);	
    
    /* hier die Ausgabefelder angeben */
    $template->assign(compact('form'));
	
	include_once('header.php');	
		$template->display("admin/main.html");
	include_once('footer.php');
}
?>